package com.delfines.business;

import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.delfines.Constante;
import com.delfines.dao.ConnectionFactory;
import com.delfines.vo.Comprobante;
import com.delfines.vo.ComprobanteDetalle;
import com.delfines.vo.ConsultaDetalleOrdenes;
import com.delfines.vo.ConsultaEstadoOrdenes;
import com.delfines.vo.ConsultaPagos;
import com.delfines.vo.Guia;
import com.delfines.vo.GuiaDetalle;
import com.delfines.vo.Usuario;

public class ReportesBo {
	
	public List<Integer> listarIdComprobante(String fechaIni,String fechaFin){
		List<Integer> lista = new ArrayList<Integer>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;
	
        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT c.id_comprobante ");
            query.append("FROM dbo.comprobante c ");
            query.append("WHERE c.fecha_comprobante BETWEEN convert(datetime, ?, 103) AND convert(datetime, ?, 103) and c.estado=2 ");
            //query.append("AND c.id_comprobante=2482--prueba ");
            
            ps = conn.prepareStatement(query.toString());
            ps.setString(1, fechaIni);
            ps.setString(2, fechaFin);
            
            rs = ps.executeQuery();
            
            while(rs.next()){
            	Integer idComprobante=rs.getInt("id_comprobante");
            	lista.add(idComprobante);
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return lista;
	}
	
	
	public List<ConsultaPagos> buscarReportePagosByFechaGuia(String fechaGuiaInicio,String fechaGuiaFin,Integer idListaPrecio,Integer idFormaPago){
		List<ConsultaPagos> lista = new ArrayList<ConsultaPagos>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;
	
        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT p.id_pago,c.id_comprobante,c.seq_mes,td.denominacion tipo_documento,e.nro_documento,e.denominacion denominacion_cliente,    ");
            query.append("convert(varchar(20),c.fecha_comprobante,103) fecha_comprobante,c.numero_comprobante,f.denominacion denominacion_forma_pago, "); 
            query.append("ISNULL(j.denominacion,'') denominacion_tipo_tarjeta,p.numero_tarjeta, "); 
            query.append("t.denominacion denominacion_tipo_moneda,  ");
            query.append("dbo.getDateTimeAMPM(p.fechahora_pago)fechahora_pago, "); 
            query.append("COALESCE(c.total_general,0) monto_pago, "); 
            query.append("u.username  ");
            query.append("FROM dbo.comprobante c ");
            query.append("INNER JOIN dbo.cliente e ON (e.id_cliente=c.id_cliente)  ");
            query.append("INNER JOIN dbo.tipo_documento td ON (td.id_tipo_documento=e.id_tipo_documento) "); 
            query.append("left JOIN dbo.pago p ON (c.id_comprobante=p.id_comprobante)  ");
            query.append("left JOIN dbo.forma_pago f ON (p.id_forma_pago=f.id_forma_pago)  ");
            query.append("left JOIN dbo.tipo_moneda t ON (t.id_tipo_moneda=p.id_tipo_moneda) "); 
            query.append("left JOIN dbo.usuario u ON (u.id_usuario=p.audit_usuarioid)  ");
            query.append("LEFT JOIN dbo.tipo_tarjeta j ON (j.id_tipo_tarjeta=p.id_tipo_tarjeta) "); 
            query.append("WHERE c.estado=2 and c.fecha_comprobante BETWEEN ? AND ? ");
            if(idListaPrecio!=null&&idListaPrecio>0){
            	query.append(" AND g.id_lista_precio = ? ");
            }
            if(idFormaPago!=null&&idFormaPago>0){
            	query.append(" AND p.id_forma_pago = ? ");
            }
            query.append("ORDER BY c.seq_mes DESC ");
            
            int index=1;
            ps = conn.prepareStatement(query.toString());
            ps.setDate(index++,Util.stringToDate(fechaGuiaInicio));
            ps.setDate(index++,Util.stringToDate(fechaGuiaFin));
            if(idListaPrecio!=null&&idListaPrecio>0){
            	ps.setInt(index++, idListaPrecio);
            }
            if(idFormaPago!=null&&idFormaPago>0){
            	ps.setInt(index++, idFormaPago);
            }
            
            rs = ps.executeQuery();
            
            while(rs.next()){
            	ConsultaPagos consulta=new ConsultaPagos(); 
            	consulta.setIdPago(rs.getInt("id_pago"));
            	consulta.setIdComprobante(rs.getInt("id_comprobante"));
            	consulta.setTipoDocumento(rs.getString("tipo_documento"));
            	consulta.setNroDocumento(rs.getString("nro_documento"));
            	consulta.setDenominacionCliente(rs.getString("denominacion_cliente"));
            	consulta.setFechaComprobante(rs.getString("fecha_comprobante"));
            	consulta.setNumeroComprobante(rs.getString("numero_comprobante"));
            	consulta.setDenominacionFormaPago(rs.getString("denominacion_forma_pago"));
            	consulta.setDenominacionTipoTarjeta(rs.getString("denominacion_tipo_tarjeta"));
            	consulta.setNumeroTarjeta(rs.getString("numero_tarjeta"));
            	consulta.setDenominacionTipoMoneda(rs.getString("denominacion_tipo_moneda"));
            	consulta.setFechaHoraPago(rs.getString("fechahora_pago"));
            	consulta.setMontoPago(rs.getDouble("monto_pago"));
            	consulta.setUsuario(rs.getString("username"));
            	//--
            	consulta.setSeqMes(rs.getInt("seq_mes"));
            	//--
            	lista.add(consulta);
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return lista;
	}
	
	
	
	public List<ConsultaEstadoOrdenes> buscarReporteEstadoOrdenesByIdGuia(Integer idGuiaIni,Integer idGuiaFin,Integer idListaPrecio,Integer estadoEntrega){
		List<ConsultaEstadoOrdenes> lista = new ArrayList<ConsultaEstadoOrdenes>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;
	
        try {
            
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT g.id_guia,g.seq_guia numero_guia,tc.abreviado denominacion_tipo_cliente,td.denominacion denominacion_tipo_documento,c.nro_documento ,c.denominacion denominacion_cliente, ");
            query.append("convert(varchar(20),g.fecha_guia,103) fecha_guia,convert(varchar(20),g.fecha_comprometida,103) fecha_comprometida,dbo.getDateTimeAMPM(g.fecha_entrega) fecha_entrega, ");
            query.append("lp.denominacion denominacion_lista_precio, ");
            query.append("p.denominacion denominacion_prioridad,g.comentario, ");
            query.append("g.total_descuento,g.total_recargo,g.total_general,g.totalneto, ");
            query.append("u.usuario ");
            query.append("FROM dbo.guia g ");
            query.append("inner join dbo.cliente c ON (c.id_cliente=g.id_cliente) ");
            query.append("inner join dbo.tipo_cliente tc ON (tc.id_tipo_cliente=c.id_tipo_cliente) ");
            query.append("inner join dbo.tipo_documento td ON (td.id_tipo_documento=c.id_tipo_documento) ");
            query.append("inner join dbo.lista_precio lp ON (g.id_lista_precio=lp.id_lista_precio) ");
            query.append("inner join dbo.prioridad p ON (p.id_prioridad=g.id_prioridad) ");
            query.append("inner join dbo.usuario u ON (u.id_usuario=g.audit_usuarioid) ");
            query.append("WHERE g.id_guia BETWEEN ? AND ? ");
            if(idListaPrecio!=null&&idListaPrecio>0){
            	query.append(" AND g.id_lista_precio = ? ");
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	query.append(" AND isnull(g.estado_entrega,0) = ? ");
            }
            query.append(" AND g.estado = 2 ");//Completado
            
            ps = conn.prepareStatement(query.toString());
            ps.setInt(1, idGuiaIni.intValue());
            ps.setInt(2, idGuiaFin.intValue());
            int index=3;
            if(idListaPrecio!=null&&idListaPrecio>0){
            	ps.setInt(index++, idListaPrecio);
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	ps.setInt(index++, estadoEntrega);
            }
            
            rs = ps.executeQuery();
            
            while(rs.next()){
            	ConsultaEstadoOrdenes consulta=new ConsultaEstadoOrdenes(); 
            	consulta.setIdGuia(rs.getInt("id_guia"));
            	consulta.setNroGuia(rs.getString("numero_guia"));
            	consulta.setTipoCliente(rs.getString("denominacion_tipo_cliente"));
            	consulta.setTipoDocumento(rs.getString("denominacion_tipo_documento"));
            	consulta.setNroDocumento(rs.getString("nro_documento"));
            	consulta.setDenominacionCliente(rs.getString("denominacion_cliente"));
            	consulta.setFechaGuia(rs.getString("fecha_guia"));
            	consulta.setFechaComprometida(rs.getString("fecha_comprometida"));
            	consulta.setFechaEntrega(rs.getString("fecha_entrega"));
            	consulta.setListaPrecio(rs.getString("denominacion_lista_precio"));
            	consulta.setPrioridad(rs.getString("denominacion_prioridad"));
            	consulta.setComentario(rs.getString("comentario"));
            	consulta.setTotalDescuento(rs.getDouble("total_descuento"));
            	consulta.setTotalRecargo(rs.getDouble("total_recargo"));
            	consulta.setTotalGeneral(rs.getDouble("total_general"));
            	consulta.setTotalNeto(rs.getDouble("totalneto"));
            	consulta.setUsuario(rs.getString("usuario"));
            	
            	lista.add(consulta);
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return lista;
	}
	
	
	public List<ConsultaEstadoOrdenes> buscarReporteEstadoOrdenesByFechaGuia(String fechaGuiaIni,String fechaGuiaFin,Integer idListaPrecio,Integer estadoEntrega){
		List<ConsultaEstadoOrdenes> lista = new ArrayList<ConsultaEstadoOrdenes>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;

        try {
            
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT g.id_guia,g.seq_guia numero_guia,tc.abreviado denominacion_tipo_cliente,td.denominacion denominacion_tipo_documento,c.nro_documento ,c.denominacion denominacion_cliente, ");
            query.append("convert(varchar(20),g.fecha_guia,103) fecha_guia,convert(varchar(20),g.fecha_comprometida,103) fecha_comprometida,dbo.getDateTimeAMPM(g.fecha_entrega) fecha_entrega, ");
            query.append("lp.denominacion denominacion_lista_precio, ");
            query.append("p.denominacion denominacion_prioridad,g.comentario, ");
            query.append("g.total_descuento,g.total_recargo,g.total_general,g.totalneto, ");
            query.append("u.username ");
            query.append(",(CASE WHEN ISNULL(g.estado_entrega,0)=1 THEN 'ENTREGADO' WHEN ISNULL(g.estado_entrega,0)=2 THEN 'PREPARADO' ELSE 'PENDIENTE' END) estado_entrega ");
            query.append("FROM dbo.guia g ");
            query.append("inner join dbo.cliente c ON (c.id_cliente=g.id_cliente) ");
            query.append("inner join dbo.tipo_cliente tc ON (tc.id_tipo_cliente=c.id_tipo_cliente) ");
            query.append("inner join dbo.tipo_documento td ON (td.id_tipo_documento=c.id_tipo_documento) ");
            query.append("inner join dbo.lista_precio lp ON (g.id_lista_precio=lp.id_lista_precio) ");
            query.append("inner join dbo.prioridad p ON (p.id_prioridad=g.id_prioridad) ");
            query.append("inner join dbo.usuario u ON (u.id_usuario=g.audit_usuarioid) ");
            query.append("WHERE g.fecha_guia BETWEEN ? AND ? ");
            if(idListaPrecio!=null&&idListaPrecio>0){
            	query.append(" AND g.id_lista_precio = ? ");
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	query.append(" AND isnull(g.estado_entrega,0) = ? ");
            }
            query.append(" AND g.estado = 2 ");//Completado
            
            ps = conn.prepareStatement(query.toString());
            ps.setDate(1, Util.stringToDate(fechaGuiaIni));
            ps.setDate(2, Util.stringToDate(fechaGuiaFin));
            int index=3;
            if(idListaPrecio!=null&&idListaPrecio>0){
            	ps.setInt(index++, idListaPrecio);
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	ps.setInt(index++, estadoEntrega);
            }
            
            rs = ps.executeQuery();
            
            while(rs.next()){
            	ConsultaEstadoOrdenes consulta=new ConsultaEstadoOrdenes(); 
            	consulta.setIdGuia(rs.getInt("id_guia"));
            	consulta.setNroGuia(rs.getString("numero_guia"));
            	consulta.setTipoCliente(rs.getString("denominacion_tipo_cliente"));
            	consulta.setTipoDocumento(rs.getString("denominacion_tipo_documento"));
            	consulta.setNroDocumento(rs.getString("nro_documento"));
            	consulta.setDenominacionCliente(rs.getString("denominacion_cliente"));
            	consulta.setFechaGuia(rs.getString("fecha_guia"));
            	consulta.setFechaComprometida(rs.getString("fecha_comprometida"));
            	consulta.setFechaEntrega(rs.getString("fecha_entrega"));
            	consulta.setListaPrecio(rs.getString("denominacion_lista_precio"));
            	consulta.setPrioridad(rs.getString("denominacion_prioridad"));
            	consulta.setComentario(rs.getString("comentario"));
            	consulta.setTotalDescuento(rs.getDouble("total_descuento"));
            	consulta.setTotalRecargo(rs.getDouble("total_recargo"));
            	consulta.setTotalGeneral(rs.getDouble("total_general"));
            	consulta.setTotalNeto(rs.getDouble("totalneto"));
            	consulta.setUsuario(rs.getString("username"));
            	consulta.setEstadoEntrega(rs.getString("estado_entrega"));
            	
            	lista.add(consulta);
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return lista;
	}
	
	
	
	public List<ConsultaDetalleOrdenes> buscarReporteDetalleOrdenesByIdGuia(Integer idGuiaIni,Integer idGuiaFin,Integer idListaPrecio,Integer estadoEntrega,Integer idClasificacion){
		List<ConsultaDetalleOrdenes> lista = new ArrayList<ConsultaDetalleOrdenes>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;
	
        try {
            
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT gd.id_guia_detalle,g.id_guia,g.seq_guia numero_guia,tc.abreviado denominacion_tipo_cliente,td.denominacion denominacion_tipo_documento,c.nro_documento ,c.denominacion denominacion_cliente, ");
            query.append("convert(varchar(20),g.fecha_guia,103) fecha_guia,convert(varchar(20),g.fecha_comprometida,103) fecha_comprometida,convert(varchar(20),g.fecha_entrega,103) fecha_entrega, ");
            query.append("g.comentario comentario_guia,u.usuario, ");
            query.append("s.denominacion servicio,s.descripcion descripcion_servicio, ");
            query.append("gd.cantidad,gd.descripcion detalle_servicio, ");
            query.append("p.denominacion prioridad,s.marca clase ");
            query.append("FROM dbo.guia_detalle gd ");
            query.append("inner join dbo.servicio s ON (s.id_servicio=gd.id_servicio) ");
            query.append("inner join dbo.guia g ON (gd.id_guia=G.id_guia) ");
            query.append("inner join dbo.cliente c ON (c.id_cliente=g.id_cliente) ");
            query.append("inner join dbo.tipo_cliente tc ON (tc.id_tipo_cliente=c.id_tipo_cliente) ");
            query.append("inner join dbo.tipo_documento td ON (td.id_tipo_documento=c.id_tipo_documento) ");
            query.append("inner join dbo.usuario u ON (u.id_usuario=g.audit_usuarioid) ");
            query.append("INNER JOIN dbo.prioridad p on (p.id_prioridad=g.id_prioridad) ");
            query.append("WHERE g.id_guia BETWEEN ? AND ? ");
            if(idListaPrecio!=null&&idListaPrecio>0){
            	query.append(" AND g.id_lista_precio = ? ");
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	query.append(" AND isnull(g.estado_entrega,0) = ? ");
            }
            
            ps = conn.prepareStatement(query.toString());
            ps.setInt(1, idGuiaIni.intValue());
            ps.setInt(2, idGuiaFin.intValue());
            int index=3;
            if(idListaPrecio!=null&&idListaPrecio>0){
            	ps.setInt(index++, idListaPrecio);
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	ps.setInt(index++, estadoEntrega);
            }

            rs = ps.executeQuery();
            
            while(rs.next()){
            	ConsultaDetalleOrdenes consulta=new ConsultaDetalleOrdenes(); 
            	consulta.setIdGuia(rs.getInt("id_guia"));
            	consulta.setNroGuia(rs.getString("numero_guia"));
            	consulta.setTipoCliente(rs.getString("denominacion_tipo_cliente"));
            	consulta.setTipoDocumento(rs.getString("denominacion_tipo_documento"));
            	consulta.setNroDocumento(rs.getString("nro_documento"));
            	consulta.setDenominacionCliente(rs.getString("denominacion_cliente"));
            	consulta.setFechaGuia(rs.getString("fecha_guia"));
            	consulta.setFechaComprometida(rs.getString("fecha_comprometida"));
            	consulta.setFechaEntrega(rs.getString("fecha_entrega"));
            	consulta.setPrioridad(rs.getString("prioridad"));
            	consulta.setUsuario(rs.getString("usuario"));
            	
            	consulta.setIdDetalleGuia(rs.getInt("id_guia_detalle"));
            	consulta.setComentarioGuia(rs.getString("comentario_guia"));
            	consulta.setServicio(rs.getString("servicio"));
            	consulta.setDescripcionServicio(rs.getString("descripcion_servicio"));
            	consulta.setCantidad(rs.getDouble("cantidad"));
            	consulta.setDetalleServicio(rs.getString("detalle_servicio"));
            	
            	consulta.setClase(rs.getString("clase"));
            	
            	lista.add(consulta);
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return lista;
	}
	
	
	public List<ConsultaDetalleOrdenes> buscarReporteDetalleOrdenesByFechaGuia(String fechaGuiaIni,String fechaGuiaFin,Integer idListaPrecio,Integer estadoEntrega,Integer idClasificacion){
		List<ConsultaDetalleOrdenes> lista = new ArrayList<ConsultaDetalleOrdenes>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;
	
        try {
            
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT gd.id_guia_detalle,g.id_guia,g.seq_guia numero_guia,tc.abreviado denominacion_tipo_cliente,td.denominacion denominacion_tipo_documento,c.nro_documento ,c.denominacion denominacion_cliente, ");
            query.append("convert(varchar(20),g.fecha_guia,103) fecha_guia,convert(varchar(20),g.fecha_comprometida,103) fecha_comprometida,convert(varchar(20),g.fecha_entrega,103) fecha_entrega, ");
            query.append("g.comentario comentario_guia,u.username, ");
            query.append("s.denominacion servicio,s.descripcion descripcion_servicio, ");
            query.append("gd.cantidad,gd.descripcion detalle_servicio, ");
            query.append("p.denominacion prioridad,s.marca clase ");
            query.append(",(CASE WHEN ISNULL(g.estado_entrega,0)=1 THEN 'ENTREGADO' WHEN ISNULL(g.estado_entrega,0)=2 THEN 'PREPARADO' ELSE 'PENDIENTE' END) estado_entrega ");
            query.append(",gd.total_linea ");
            query.append("FROM dbo.guia_detalle gd ");
            query.append("inner join dbo.servicio s ON (s.id_servicio=gd.id_servicio) ");
            query.append("inner join dbo.guia g ON (gd.id_guia=G.id_guia) ");
            query.append("inner join dbo.cliente c ON (c.id_cliente=g.id_cliente) ");
            query.append("inner join dbo.tipo_cliente tc ON (tc.id_tipo_cliente=c.id_tipo_cliente) ");
            query.append("inner join dbo.tipo_documento td ON (td.id_tipo_documento=c.id_tipo_documento) ");
            query.append("inner join dbo.usuario u ON (u.id_usuario=g.audit_usuarioid) ");
            query.append("INNER JOIN dbo.prioridad p on (p.id_prioridad=g.id_prioridad) ");
            query.append("WHERE g.fecha_guia BETWEEN ? AND ? ");
            if(idListaPrecio!=null&&idListaPrecio>0){
            	query.append(" AND g.id_lista_precio = ? ");
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	query.append(" AND isnull(g.estado_entrega,0) = ? ");
            }
            if(idClasificacion!=null&&idClasificacion>0){
            	query.append(" AND s.marca = ? ");
            }
            query.append(" AND g.estado = 2 and gd.estado=1 ");//Completado
            
            ps = conn.prepareStatement(query.toString());
            ps.setDate(1, Util.stringToDate(fechaGuiaIni));
            ps.setDate(2, Util.stringToDate(fechaGuiaFin));
            int index=3;
            if(idListaPrecio!=null&&idListaPrecio>0){
            	ps.setInt(index++, idListaPrecio);
            }
            if(estadoEntrega!=null&&estadoEntrega<9){
            	ps.setInt(index++, estadoEntrega);
            }
            if(idClasificacion!=null&&idClasificacion>0){
            	ps.setString(index++, idClasificacion==1?Constante.DEN_CLASIF_VALET_EXT:Constante.DEN_CLASIF_ADREDOMERO);
            }
            
            rs = ps.executeQuery();
            
            while(rs.next()){
            	ConsultaDetalleOrdenes consulta=new ConsultaDetalleOrdenes(); 
            	consulta.setIdGuia(rs.getInt("id_guia"));
            	consulta.setNroGuia(rs.getString("numero_guia"));
            	consulta.setTipoCliente(rs.getString("denominacion_tipo_cliente"));
            	consulta.setTipoDocumento(rs.getString("denominacion_tipo_documento"));
            	consulta.setNroDocumento(rs.getString("nro_documento"));
            	consulta.setDenominacionCliente(rs.getString("denominacion_cliente"));
            	consulta.setFechaGuia(rs.getString("fecha_guia"));
            	consulta.setFechaComprometida(rs.getString("fecha_comprometida"));
            	consulta.setFechaEntrega(rs.getString("fecha_entrega"));
            	consulta.setPrioridad(rs.getString("prioridad"));
            	consulta.setUsuario(rs.getString("username"));
            	
            	consulta.setIdDetalleGuia(rs.getInt("id_guia_detalle"));
            	consulta.setComentarioGuia(rs.getString("comentario_guia"));
            	consulta.setServicio(rs.getString("servicio"));
            	consulta.setDescripcionServicio(rs.getString("descripcion_servicio"));
            	consulta.setCantidad(rs.getDouble("cantidad"));
            	consulta.setDetalleServicio(rs.getString("detalle_servicio"));
            	
            	consulta.setClase(rs.getString("clase"));
            	consulta.setEstadoEntrega(rs.getString("estado_entrega"));
            	consulta.setTotalLinea(rs.getDouble("total_linea"));
            	lista.add(consulta);
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return lista;
	}
	
	
	
	
	
	
	
	
	/**
	 * corregir esta vaina
	 */
	
	
	
	
	
	
	
	
	
	
	
	
	/**
	 * Lista de guias 
	 */
	public List<ConsultaEstadoOrdenes> buscarListaGuiaByFechaGuia(Integer idCliente,Integer idGrupo){
		List<ConsultaEstadoOrdenes> lista = new ArrayList<ConsultaEstadoOrdenes>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;

        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT g.id_guia,g.seq_guia numero_guia,tc.abreviado denominacion_tipo_cliente,td.denominacion denominacion_tipo_documento,c.nro_documento ,c.denominacion denominacion_cliente, ");
            query.append("convert(varchar(20),g.fecha_guia,103) fecha_guia,convert(varchar(20),g.fecha_comprometida,103) fecha_comprometida,dbo.getDateTimeAMPM(g.fecha_entrega) fecha_entrega, ");
            query.append("lp.denominacion denominacion_lista_precio, ");
            query.append("p.denominacion denominacion_prioridad,g.comentario, ");
            query.append("g.total_descuento,g.total_recargo,g.total_general,g.totalneto, ");
            query.append("u.username, ");
            query.append("c.id_cliente ");
            query.append("FROM dbo.guia g ");
            query.append("inner join dbo.cliente c ON (c.id_cliente=g.id_cliente) ");
            query.append("inner join dbo.tipo_cliente tc ON (tc.id_tipo_cliente=c.id_tipo_cliente) ");
            query.append("inner join dbo.tipo_documento td ON (td.id_tipo_documento=c.id_tipo_documento) ");
            query.append("inner join dbo.lista_precio lp ON (g.id_lista_precio=lp.id_lista_precio) ");
            query.append("inner join dbo.prioridad p ON (p.id_prioridad=g.id_prioridad) ");
            query.append("inner join dbo.usuario u ON (u.id_usuario=g.audit_usuarioid) ");
            query.append("left join dbo.guia_comprobante gc ON (gc.id_guia=g.id_guia) ");
            query.append("WHERE (ISNULL(gc.id_guia,0)=0) ");
            query.append("AND g.id_guia NOT IN (SELECT id_guia from dbo.guia_grupo where id_grupo=? and estado=1) ");
            
            if(idCliente!=null&&idCliente>0){
            	query.append(" AND g.id_cliente = ? ");
            }
            	
            query.append(" AND g.estado = 2 ");//Completado
            
            ps = conn.prepareStatement(query.toString());
            
            int index=1;
            ps.setInt(index++, idGrupo);
            if(idCliente!=null&&idCliente>0){
            	ps.setInt(index++, idCliente);
            }
            
            rs = ps.executeQuery();
            
            while(rs.next()){
            	ConsultaEstadoOrdenes consulta=new ConsultaEstadoOrdenes(); 
            	consulta.setIdGuia(rs.getInt("id_guia"));
            	consulta.setNroGuia(rs.getString("numero_guia"));
            	consulta.setTipoCliente(rs.getString("denominacion_tipo_cliente"));
            	consulta.setTipoDocumento(rs.getString("denominacion_tipo_documento"));
            	consulta.setNroDocumento(rs.getString("nro_documento"));
            	consulta.setDenominacionCliente(rs.getString("denominacion_cliente"));
            	consulta.setFechaGuia(rs.getString("fecha_guia"));
            	consulta.setFechaComprometida(rs.getString("fecha_comprometida"));
            	consulta.setFechaEntrega(rs.getString("fecha_entrega"));
            	consulta.setListaPrecio(rs.getString("denominacion_lista_precio"));
            	consulta.setPrioridad(rs.getString("denominacion_prioridad"));
            	consulta.setComentario(rs.getString("comentario"));
            	consulta.setTotalDescuento(rs.getDouble("total_descuento"));
            	consulta.setTotalRecargo(rs.getDouble("total_recargo"));
            	consulta.setTotalGeneral(rs.getDouble("total_general"));
            	consulta.setTotalNeto(rs.getDouble("totalneto"));
            	consulta.setUsuario(rs.getString("username"));
            	consulta.setIdCliente(rs.getInt("id_cliente"));
            	lista.add(consulta);
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        return lista;
	}

	public List<ConsultaEstadoOrdenes> listarGuiaByGrupo(Integer idGrupo){
		List<ConsultaEstadoOrdenes> lista = new ArrayList<ConsultaEstadoOrdenes>();
		
		PreparedStatement ps=null;
		ResultSet rs=null;

        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT g.id_guia,g.seq_guia numero_guia,tc.abreviado denominacion_tipo_cliente,td.denominacion denominacion_tipo_documento,c.nro_documento ,c.denominacion denominacion_cliente, ");
            query.append("convert(varchar(20),g.fecha_guia,103) fecha_guia,convert(varchar(20),g.fecha_comprometida,103) fecha_comprometida,dbo.getDateTimeAMPM(g.fecha_entrega) fecha_entrega, ");
            query.append("lp.denominacion denominacion_lista_precio, ");
            query.append("p.denominacion denominacion_prioridad,g.comentario, ");
            query.append("g.total_descuento,g.total_recargo,g.total_general,g.totalneto, ");
            query.append("u.username ");
            query.append("FROM dbo.guia g ");
            query.append("INNER JOIN dbo.guia_grupo gg ON (gg.id_guia=g.id_guia and gg.estado=1) ");
            query.append("inner join dbo.cliente c ON (c.id_cliente=g.id_cliente) ");
            query.append("inner join dbo.tipo_cliente tc ON (tc.id_tipo_cliente=c.id_tipo_cliente) ");
            query.append("inner join dbo.tipo_documento td ON (td.id_tipo_documento=c.id_tipo_documento) ");
            query.append("inner join dbo.lista_precio lp ON (g.id_lista_precio=lp.id_lista_precio) ");
            query.append("inner join dbo.prioridad p ON (p.id_prioridad=g.id_prioridad) ");
            query.append("inner join dbo.usuario u ON (u.id_usuario=g.audit_usuarioid) ");
            query.append("WHERE gg.id_grupo=? ");//Completado
            
            ps = conn.prepareStatement(query.toString());
            ps.setInt(1, idGrupo);
            
            rs = ps.executeQuery();
            
            while(rs.next()){
            	ConsultaEstadoOrdenes consulta=new ConsultaEstadoOrdenes(); 
            	consulta.setIdGuia(rs.getInt("id_guia"));
            	consulta.setNroGuia(rs.getString("numero_guia"));
            	consulta.setTipoCliente(rs.getString("denominacion_tipo_cliente"));
            	consulta.setTipoDocumento(rs.getString("denominacion_tipo_documento"));
            	consulta.setNroDocumento(rs.getString("nro_documento"));
            	consulta.setDenominacionCliente(rs.getString("denominacion_cliente"));
            	consulta.setFechaGuia(rs.getString("fecha_guia"));
            	consulta.setFechaComprometida(rs.getString("fecha_comprometida"));
            	consulta.setFechaEntrega(rs.getString("fecha_entrega"));
            	consulta.setListaPrecio(rs.getString("denominacion_lista_precio"));
            	consulta.setPrioridad(rs.getString("denominacion_prioridad"));
            	consulta.setComentario(rs.getString("comentario"));
            	consulta.setTotalDescuento(rs.getDouble("total_descuento"));
            	consulta.setTotalRecargo(rs.getDouble("total_recargo"));
            	consulta.setTotalGeneral(rs.getDouble("total_general"));
            	consulta.setTotalNeto(rs.getDouble("totalneto"));
            	consulta.setUsuario(rs.getString("username"));
           		lista.add(consulta);	
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return lista;
	}
	
	public Integer getIdGrupo(){
		CallableStatement cs = null;
		
		Integer idGrupo=0;
		
        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("{ call dbo.GET_ID_GRUPO(?) }");
            
            cs = conn.prepareCall(query.toString());
            cs.registerOutParameter(1, java.sql.Types.VARCHAR);  
            //--
            cs.execute();
            idGrupo=cs.getInt(1);
              
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } finally {
        	if (cs != null) {try {cs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        return idGrupo;
	}
	
	
	public Integer obtenerClienteGrupo(Integer pidGrupo){
		PreparedStatement ps=null;
		ResultSet rs=null;
		Integer pk=0;
        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("SELECT isnull(max(g.id_cliente),0) id_cliente "); 
            query.append("FROM dbo.guia_grupo gg  ");
            query.append("INNER JOIN dbo.guia g on (g.id_guia=gg.id_guia) "); 
            query.append("WHERE gg.id_grupo=? ");
            
            ps = conn.prepareStatement(query.toString());
            ps.setInt(1, pidGrupo);
            //--
            rs = ps.executeQuery();
            
            if(rs.next()){
            	pk=rs.getInt("id_cliente");
            }
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        return pk;
	}
	
	public Integer registraGrupoGuia(Integer idGuia,Integer idGrupo,Usuario pUsuario){
		PreparedStatement ps=null;
		ResultSet rs=null;
		Integer pk=0;
        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("INSERT INTO dbo.guia_grupo(id_guia,id_grupo,audit_fecha,estado)VALUES(?,?,getdate(),1) ");
            
            ps = conn.prepareStatement(query.toString());
            ps.setInt(1, idGuia);
            ps.setInt(2, idGrupo);
            //--
            if(ps.executeUpdate()>0){
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return pk;
	}
	
	public Integer eliminaGrupoGuia(Integer idGuia,Integer idGrupo,Usuario pUsuario){
		PreparedStatement ps=null;
		ResultSet rs=null;
		Integer pk=0;
        try {
        	Connection conn = ConnectionFactory.getInstance().getConnection();
            
            StringBuilder query = new StringBuilder();
            query.append("DELETE FROM dbo.guia_grupo where id_guia=? and id_grupo=? ");
            
            ps = conn.prepareStatement(query.toString());
            ps.setInt(1, idGuia);
            ps.setInt(2, idGrupo);
            //--
            if(ps.executeUpdate()>0){
            }
            
        } catch (SQLException e) {
            throw new RuntimeException(e);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }finally {
        	if (ps != null) {try {ps.close();} catch (SQLException e) {e.printStackTrace();}}
            if (rs != null) {try {rs.close();} catch (SQLException e) {e.printStackTrace();}}
        }
        
        return pk;
	}
	
	
	
}
