package com.delfines.spring.controller;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.List;
import java.util.Properties;

import com.delfines.business.ClienteBo;
import com.delfines.business.RegistroFacturaBo;
import com.delfines.business.Util;
import com.delfines.vo.Cliente;
import com.delfines.vo.Comprobante;
import com.delfines.vo.ComprobanteDetalle;
import com.delfines.vo.ComprobanteDetalleDBF;
import com.delfines.vo.TipoCambio;
import com.linuxense.javadbf.DBFException;
import com.linuxense.javadbf.DBFReader;

public class JavaDBFWrite {
	private static String sJdbURL;
	
	public static String getsJdbURL() {
		return sJdbURL;
	}

	public static void setsJdbURL(String sJdbURL) {
		JavaDBFWrite.sJdbURL = sJdbURL;
	}

	private String folderName;
	
	public String getFolderName() {
		return folderName;
	}

	public void setFolderName(String folderName) {
		this.folderName = folderName;
	}
	
	public JavaDBFWrite(String fechaComp){
		try{
			ClienteBo cliente=new ClienteBo();
			String folder=cliente.getDateFolder(fechaComp);
			Util.createFolderCONCAR(folder);
			setFolderName(Util.pathCONCAR+folder+"\\");
			setsJdbURL("jdbc:dbf://"+getFolderName()+"/?caseInsensitive=true");
		}catch(Exception e){
			e.printStackTrace();
			setFolderName(Util.pathCONCAR);
			setsJdbURL("jdbc:dbf://"+getFolderName()+"/?caseInsensitive=true");
	    }
	}
	
	public Integer createDBFConcar(String fechaComprobante)throws Exception,DBFException, IOException,ParseException {
		Integer cantidad=0;
		RegistroFacturaBo bo=new RegistroFacturaBo();
	    
		Integer periodo=Util.getYear(fechaComprobante);
		
		TipoCambio tipoCambio=bo.obtenerTipoCambioVenta(fechaComprobante);
		if(tipoCambio!=null && tipoCambio.getTipoCambioVenta()>0){
			//Calculo de valores US
			bo.calcularUSValores(fechaComprobante);
			
			List<Comprobante> lHeader=bo.listaComprobante(fechaComprobante);
			cantidad=lHeader.size();
			if(cantidad>0){
				List<ComprobanteDetalleDBF> lDetail=bo.obtenerComprobanteDetalleDBF(fechaComprobante);
				createCabeceraDBF(periodo,lHeader,tipoCambio);
			    createDetalleDBF(periodo,lDetail);
			    
			    List<Cliente> lCliente=bo.listaCliente(fechaComprobante);
			    createAnexoDBF(lCliente);
			}
		}else{
			throw new Exception("No registra tipo de cambio para la fecha"+fechaComprobante);
		}
		return cantidad;
	}
	
	
	public void createCabeceraDBF(Integer periodo,List<Comprobante> lheader,TipoCambio cambio)throws DBFException, IOException,ParseException {
		  try{
			  Class.forName("com.caigen.sql.dbf.DBFDriver");

              Properties props = new Properties();
              props.setProperty("delayedClose", "0");
              props.setProperty("versionNumber", "F5");
              
              Connection conn = DriverManager.getConnection(getsJdbURL(), props);
              Statement stmt = conn.createStatement(ResultSet.TYPE_SCROLL_SENSITIVE, ResultSet.CONCUR_UPDATABLE);

              String sql="drop table if exists CC0002"+String.valueOf(periodo)+";";
              stmt.execute(sql);
              
              sql="create table if not exists CC0002"+String.valueOf(periodo)+"(CSUBDIA CHAR(4),CCOMPRO CHAR(6),CFECCOM CHAR(6),CCODMON CHAR(2),CSITUA CHAR(1),CTIPCAM NUMERIC(9,4),CGLOSA CHAR(40),CTOTAL NUMERIC(13,2),CTIPO CHAR(1),CFLAG CHAR(1),CDATE DATE,CHORA CHAR(6),CFECCAM CHAR(6),CUSER CHAR(5),CORIG CHAR(2),CFORM CHAR(1),CTIPCOM CHAR(2),CEXTOR CHAR(1) );";
              stmt.execute(sql);
	              
              for(Comprobante header:lheader){
	              //ASIGNA DATA :: INICIO
	              Object []rowObjects=new Object [18];
	              rowObjects[0]="05C";//CSUBDIA
	              rowObjects[1]=header.getCcompro();//CCOMPRO
	              rowObjects[2]=header.getFechaComprobanteYYMMDD();//CFECCOM
	              rowObjects[3]="MN";//CCODMON
	              rowObjects[4]="F";//CSITUA
	              rowObjects[5]=cambio.getTipoCambioVenta();//CTIPCAM
	              rowObjects[6]="VENTAS LAVANDERIA";//CGLOSA
	              rowObjects[7]=header.getTotalGeneral();//CTOTAL
	              rowObjects[8]="V";//CTIPO
	              rowObjects[9]="S";//CFLAG
	              rowObjects[10]=header.getFechaComprobanteMMDDYYYY();//CDATE
	              rowObjects[11]=header.getHoraComprobanteHHMM();//CHORA
	              rowObjects[12]=cambio.getFechaCambioYYMMDD();//CFECCAM
	              rowObjects[13]="ILAV";//CUSER
	              rowObjects[14]="LV";//CORIG
	              rowObjects[15]="A";//CFORM
	              rowObjects[16]="V";//CTIPCOM
	              rowObjects[17]="";//CEXTOR
	              //ASIGNA DATA :: FIN
	              
		    		StringBuilder query = new StringBuilder();
		    		query.append("insert into CC0002"+String.valueOf(periodo)+"(CSUBDIA,CCOMPRO,CFECCOM,CCODMON,CSITUA,CTIPCAM,CGLOSA,CTOTAL,CTIPO,CFLAG,CDATE,CHORA,CFECCAM,CUSER,CORIG,CFORM,CTIPCOM,CEXTOR) values(");
		    		query.append("'"+rowObjects[0]+"',");//CSUBDIA 4 0 67
		    		query.append("'"+rowObjects[1]+"',");//CCOMPRO 6 0 67
		    		query.append("'"+rowObjects[2]+"',");//CFECCOM 6 0 67
		    		query.append("'"+rowObjects[3]+"',");//CCODMON 2 0 67
		    		query.append("'"+rowObjects[4]+"',");//CSITUA 1 0 67
		    		query.append(new Double(rowObjects[5]==null?"0.0":rowObjects[5].toString())+",");//    CTIPCAM 10 4 78
		    		query.append("'"+rowObjects[6]+"',");//CGLOSA 40 0 67
		    		query.append(new Double(rowObjects[7]==null?"0.0":rowObjects[7].toString())+",");//CTOTAL 14 2 78
		    		query.append("'"+rowObjects[8]+"',");//CTIPO 1 0 67
		    		query.append("'"+rowObjects[9]+"',");//CFLAG 1 0 67
		    		
		    		if(rowObjects[10]!=null){
		    			DateFormat df = new SimpleDateFormat("MM/dd/yyyy");
				        GregorianCalendar calendar = new GregorianCalendar();
						calendar.setTime(df.parse(rowObjects[10].toString()));
						
						String year=String.valueOf(calendar.get(Calendar.YEAR));
						String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
						month=fill(month,2);
						String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
						day=fill(day,2);
						
						query.append("CDATE('"+month+day+year+"','MMddyyyy'),");//CDATE 8 0 68
		    		}else{
		    			query.append("'',");
		    		}
		    		query.append("'"+rowObjects[11]+"',");//CHORA CHAR(6),
		    		query.append("'"+rowObjects[12]+"',");//CFECCAM CHAR(6),
		    		query.append("'"+rowObjects[13]+"',");//CUSER CHAR(5),
		    		query.append("'"+rowObjects[14]+"',");//CORIG 2 0 67
		    		query.append("'"+rowObjects[15]+"',");//CFORM 1 0 67
		    		query.append("'"+rowObjects[16]+"',");//CTIPCOM 2 0 67
		    		query.append("'"+rowObjects[17]+"'");//CEXTOR 1 0 67
		    		query.append(");");
		    		
		    		System.out.println(query.toString());
		            stmt.execute(query.toString());
                }
			    stmt.close();
	            conn.close();
	        }
	        catch( SQLException sqle )
	        {
	            do
	            {
	                System.out.println(sqle.getMessage());
	                System.out.println("Error Code:"+sqle.getErrorCode());
	                System.out.println("SQL State:"+sqle.getSQLState());
	                sqle.printStackTrace();
	            }while((sqle=sqle.getNextException())!=null);
	        }
	        catch( Exception e )
	        {
	            System.out.println(e.getMessage());
	            e.printStackTrace();
	        }
    }
	
	
	public void createDetalleDBF(Integer periodo,List<ComprobanteDetalleDBF> lDetalle)throws DBFException, IOException,ParseException {
		  try{
              Class.forName("com.caigen.sql.dbf.DBFDriver");

              Properties props = new Properties();
              props.setProperty("delayedClose", "0");
              props.setProperty("versionNumber", "F5");

              Connection conn = DriverManager.getConnection(getsJdbURL(), props);
              Statement stmt = conn.createStatement(ResultSet.TYPE_SCROLL_SENSITIVE, ResultSet.CONCUR_UPDATABLE);

              String sql="drop table if exists CD0002"+String.valueOf(periodo)+";";
              stmt.execute(sql);
              
              sql="create table if not exists CD0002"+String.valueOf(periodo)+"(DSUBDIA CHAR(4),DCOMPRO CHAR(6),DSECUE CHAR(4),DFECCOM CHAR(6),DCUENTA CHAR(12),DCODANE CHAR(18),DCENCOS CHAR(6),DCODMON CHAR(2),DDH CHAR(1),DIMPORT NUMERIC(13,2),DTIPDOC CHAR(2),DNUMDOC VARCHAR(20),DFECDOC CHAR(6),DFECVEN CHAR(6),DAREA CHAR(3),DFLAG CHAR(1),DXGLOSA VARCHAR(30),DDATE DATE,DCODANE2 CHAR(18),DUSIMPOR NUMERIC(13,2),DMNIMPOR NUMERIC(13,2),DCODARC CHAR(2),FLAGX CHAR(1),DMEDPAG CHAR(8),DIGVCOM NUMERIC(13,2),DTIDREF CHAR(2),DNDOREF CHAR(30),DFECREF DATE,DBIMREF NUMERIC(13,2),DIGVREF NUMERIC(13,2),DMAQREF CHAR(20) );";
              stmt.execute(sql);
              
              for(ComprobanteDetalleDBF detalle:lDetalle){
              //(1)
		    	  //ASIGNA DATA :: INICIO
		    	  Object []rowObjects=new Object [31];
	              rowObjects[0]="05C";//CSUBDIA
	              rowObjects[1]=detalle.getCcompro();//CCOMPRO
	              rowObjects[2]="0001";//DSECUE 4 0 67
	              rowObjects[3]=detalle.getFechaComprobanteYYMMDD();//DFECCOM 6 0 67
	              rowObjects[4]="121201";//DCUENTA 12 0 67
	              rowObjects[5]=detalle.getNroDocumentoCliente();//DCODANE 18 0 67
	              rowObjects[6]="";//DCENCOS 6 0 67
	              rowObjects[7]="MN";//DCODMON
	              rowObjects[8]="D";//DDH
	              rowObjects[9]=detalle.getTotalLineaMN();//DIMPORT
	              rowObjects[10]=detalle.getTipoComprobante();//DTIPDOC 2 0 67
	              rowObjects[11]=detalle.getNumeroComprobante();//DNUMDOC 2 0 67
	              rowObjects[12]=detalle.getFechaComprobanteYYMMDD();//DFECDOC 2 0 67
	              rowObjects[13]=detalle.getFechaComprobanteYYMMDD();//DFECVEN 2 0 67
	              rowObjects[14]="";//DAREA 2 0 67
	              rowObjects[15]="S";//DFLAG FLAG DE CONVERSIN DE MONEDA (S, N) 
	              rowObjects[16]=detalle.getDenominacionCliente();//DXGLOSA GLOSA DEL MOVIMIENTO 
	              rowObjects[17]=detalle.getFechaComprobanteMMDDYYYY();//DDATE FECHA DE ACTUALIZACIN 
	              rowObjects[18]="";//DCODANE2 CDIGO DE ANEXO AUXILAR
	              rowObjects[19]=detalle.getTotalLineaUS();//DUSIMPOR NUMERIC(14,2),
	              rowObjects[20]=detalle.getTotalLineaMN();//DMNIMPOR NUMERIC(14,2),
	              rowObjects[21]="";//DCODARC
	              rowObjects[22]="";//FLAGX
	              rowObjects[23]="";//DMEDPAG
	              rowObjects[24]="0";//DIGVCOM NUMERIC(14,2),
	              rowObjects[25]="";//DTIDREF
	              rowObjects[26]="";//DNDOREF
	              rowObjects[27]="30/12/1899";//DFECREF
	              rowObjects[28]="0";//DBIMREF
	              rowObjects[29]="0";//DIGVREF
	              rowObjects[30]="";//DMAQREF
	              //ASIGNA DATA :: FIN 
		    	  
		    		StringBuilder query = new StringBuilder();
		    		query.append("insert into CD0002"+String.valueOf(periodo)+"(DSUBDIA,DCOMPRO,DSECUE,DFECCOM,DCUENTA,DCODANE,DCENCOS,DCODMON,DDH,DIMPORT,DTIPDOC,DNUMDOC,DFECDOC,DFECVEN,DAREA,DFLAG,DXGLOSA,DDATE,DCODANE2,DUSIMPOR,DMNIMPOR,DCODARC,FLAGX,DMEDPAG,DIGVCOM,DTIDREF,DNDOREF,DFECREF,DBIMREF,DIGVREF,DMAQREF) values(");
		    		query.append("'"+rowObjects[0]+"',");//DSUBDIA 4 0 67
		    		query.append("'"+rowObjects[1]+"',");//DCOMPRO 6 0 67
		    		query.append("'"+rowObjects[2]+"',");//DSECUE 4 0 67
		    		query.append("'"+rowObjects[3]+"',");//DFECCOM 6 0 67
		    		query.append("'"+rowObjects[4]+"',");//DCUENTA 12 0 67
		    		query.append("'"+rowObjects[5]+"',");//DCODANE 18 0 67
		    		query.append("'"+rowObjects[6]+"',");//DCENCOS 6 0 67
		    		query.append("'"+rowObjects[7]+"',");//DCODMON 2 0 67
		    		query.append("'"+rowObjects[8]+"',");//DDH 1 0 67
		    		query.append(new Double(rowObjects[9]==null?"0.0":rowObjects[9].toString())+",");//DIMPORT 14 2 78
		    		query.append("'"+rowObjects[10]+"',");//DTIPDOC 2 0 67
		    		query.append("'"+rowObjects[11]+"',");//DNUMDOC 20 0 67
		    		query.append("'"+rowObjects[12]+"',");//DFECDOC 6 0 67
		    		query.append("'"+rowObjects[13]+"',");//DFECVEN 6 0 67
		    		query.append("'"+rowObjects[14]+"',");//DAREA 3 0 67
		    		query.append("'"+rowObjects[15]+"',");//DFLAG 1 0 67
		    		query.append("'"+rowObjects[16]+"',");//DXGLOSA 30 0 67
		    		
		    		if(rowObjects[17]!=null){
		    			DateFormat df = new SimpleDateFormat("MM/dd/yyyy");
				        GregorianCalendar calendar = new GregorianCalendar();
				        calendar.setTime(df.parse(rowObjects[17].toString()));
						
						String year=String.valueOf(calendar.get(Calendar.YEAR));
						String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
						month=fill(month,2);
						String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
						day=fill(day,2);
						
						query.append("CDATE('"+month+day+year+"','MMddyyyy'),");//CDATE 8 0 68
		    		}else{
		    			query.append("'',");
		    		}
		    		query.append("'"+rowObjects[18]+"',");//DCODANE2 CHAR(18),
		    		query.append(new Double(rowObjects[19]==null?"0.0":rowObjects[19].toString())+",");//DUSIMPOR NUMERIC(14,2),
		    		query.append(new Double(rowObjects[20]==null?"0.0":rowObjects[20].toString())+",");//DMNIMPOR NUMERIC(14,2),
		    		query.append("'"+rowObjects[21]+"',");//DCODARC CHAR(2),
		    		query.append("'"+rowObjects[22]+"',");//FLAGX CHAR(1),
		    		query.append("'"+rowObjects[23]+"',");//DMEDPAG CHAR(8),
		    		query.append(new Double(rowObjects[24]==null?"0.0":rowObjects[24].toString())+",");//DIGVCOM NUMERIC(14,2),
		    		query.append("'"+rowObjects[25]+"',");//DTIDREF CHAR(2),
		    		query.append("'"+rowObjects[26]+"',");//DNDOREF CHAR(30),
		    		
		    		if(rowObjects[27]!=null){
		    			DateFormat df = new SimpleDateFormat("dd/MM/yyyy");
				        GregorianCalendar calendar = new GregorianCalendar();
						calendar.setTime(df.parse(rowObjects[27].toString()));
						
						String year=String.valueOf(calendar.get(Calendar.YEAR));
						String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
						month=fill(month,2);
						String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
						day=fill(day,2);
						
						query.append("CDATE('"+day+month+year+"','ddMMyyyy'),");//DFECREF DATE,
		    		}else{
		    			query.append("'',");
		    		}
		    		
		    		query.append(new Double(rowObjects[28]==null?"0.0":rowObjects[28].toString())+",");//DBIMREF NUMERIC(14,2),
		    		query.append(new Double(rowObjects[29]==null?"0.0":rowObjects[29].toString())+",");//DIGVREF NUMERIC(14,2),
		    		query.append("'"+rowObjects[30]+"'");//DMAQREF CHAR(20)
		    		
		    		query.append(");");
		    		
		    		System.out.println(query.toString());
	                stmt.execute(query.toString());
	                
	          //(2)
		    	  //ASIGNA DATA :: INICIO
		    	  rowObjects=new Object [31];
	              rowObjects[0]="05C";//CSUBDIA
	              rowObjects[1]=detalle.getCcompro();//CCOMPRO
	              rowObjects[2]="0002";//DSECUE 4 0 67
	              rowObjects[3]=detalle.getFechaComprobanteYYMMDD();//DFECCOM 6 0 67
	              rowObjects[4]="401111";//DCUENTA 12 0 67
	              rowObjects[5]="";//DCODANE 18 0 67
	              rowObjects[6]="";//DCENCOS 6 0 67
	              rowObjects[7]="MN";//DCODMON
	              rowObjects[8]="H";//DDH
	              rowObjects[9]=detalle.getIgvMN();//DIMPORT
	              rowObjects[10]="";//DTIPDOC 2 0 67
	              rowObjects[11]="";//DNUMDOC 2 0 67
	              rowObjects[12]=detalle.getFechaComprobanteYYMMDD();//DFECDOC 2 0 67
	              rowObjects[13]=detalle.getFechaComprobanteYYMMDD();//DFECVEN 2 0 67
	              rowObjects[14]="";//DAREA 2 0 67
	              rowObjects[15]="S";//DFLAG FLAG DE CONVERSIN DE MONEDA (S, N) 
	              rowObjects[16]="";//DXGLOSA GLOSA DEL MOVIMIENTO 
	              rowObjects[17]=detalle.getFechaComprobanteMMDDYYYY();//DDATE FECHA DE ACTUALIZACIN 
	              rowObjects[18]="";//DCODANE2 CDIGO DE ANEXO AUXILAR
	              rowObjects[19]=detalle.getIgvUS();//DUSIMPOR NUMERIC(14,2),
	              rowObjects[20]=detalle.getIgvMN();//DMNIMPOR NUMERIC(14,2),
	              rowObjects[21]="";//DCODARC
	              rowObjects[22]="";//FLAGX
	              rowObjects[23]="";//DMEDPAG
	              rowObjects[24]="0";//DIGVCOM NUMERIC(14,2),
	              rowObjects[25]="";//DTIDREF
	              rowObjects[26]="";//DNDOREF
	              rowObjects[27]="30/12/1899";//DFECREF
	              rowObjects[28]="0";//DBIMREF
	              rowObjects[29]="0";//DIGVREF
	              rowObjects[30]="";//DMAQREF
	              //ASIGNA DATA :: FIN 
		    	  
		    		query = new StringBuilder();
		    		query.append("insert into CD0002"+String.valueOf(periodo)+"(DSUBDIA,DCOMPRO,DSECUE,DFECCOM,DCUENTA,DCODANE,DCENCOS,DCODMON,DDH,DIMPORT,DTIPDOC,DNUMDOC,DFECDOC,DFECVEN,DAREA,DFLAG,DXGLOSA,DDATE,DCODANE2,DUSIMPOR,DMNIMPOR,DCODARC,FLAGX,DMEDPAG,DIGVCOM,DTIDREF,DNDOREF,DFECREF,DBIMREF,DIGVREF,DMAQREF) values(");
		    		query.append("'"+rowObjects[0]+"',");//DSUBDIA 4 0 67
		    		query.append("'"+rowObjects[1]+"',");//DCOMPRO 6 0 67
		    		query.append("'"+rowObjects[2]+"',");//DSECUE 4 0 67
		    		query.append("'"+rowObjects[3]+"',");//DFECCOM 6 0 67
		    		query.append("'"+rowObjects[4]+"',");//DCUENTA 12 0 67
		    		query.append("'"+rowObjects[5]+"',");//DCODANE 18 0 67
		    		query.append("'"+rowObjects[6]+"',");//DCENCOS 6 0 67
		    		query.append("'"+rowObjects[7]+"',");//DCODMON 2 0 67
		    		query.append("'"+rowObjects[8]+"',");//DDH 1 0 67
		    		query.append(new Double(rowObjects[9]==null?"0.0":rowObjects[9].toString())+",");//DIMPORT 14 2 78
		    		query.append("'"+rowObjects[10]+"',");//DTIPDOC 2 0 67
		    		query.append("'"+rowObjects[11]+"',");//DNUMDOC 20 0 67
		    		query.append("'"+rowObjects[12]+"',");//DFECDOC 6 0 67
		    		query.append("'"+rowObjects[13]+"',");//DFECVEN 6 0 67
		    		query.append("'"+rowObjects[14]+"',");//DAREA 3 0 67
		    		query.append("'"+rowObjects[15]+"',");//DFLAG 1 0 67
		    		query.append("'"+rowObjects[16]+"',");//DXGLOSA 30 0 67
		    		
		    		if(rowObjects[17]!=null){
		    			DateFormat df = new SimpleDateFormat("MM/dd/yyyy");
				        GregorianCalendar calendar = new GregorianCalendar();
				        calendar.setTime(df.parse(rowObjects[17].toString()));
						
						String year=String.valueOf(calendar.get(Calendar.YEAR));
						String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
						month=fill(month,2);
						String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
						day=fill(day,2);
						
						query.append("CDATE('"+month+day+year+"','MMddyyyy'),");//CDATE 8 0 68
		    		}else{
		    			query.append("'',");
		    		}
		    		query.append("'"+rowObjects[18]+"',");//DCODANE2 CHAR(18),
		    		query.append(new Double(rowObjects[19]==null?"0.0":rowObjects[19].toString())+",");//DUSIMPOR NUMERIC(14,2),
		    		query.append(new Double(rowObjects[20]==null?"0.0":rowObjects[20].toString())+",");//DMNIMPOR NUMERIC(14,2),
		    		query.append("'"+rowObjects[21]+"',");//DCODARC CHAR(2),
		    		query.append("'"+rowObjects[22]+"',");//FLAGX CHAR(1),
		    		query.append("'"+rowObjects[23]+"',");//DMEDPAG CHAR(8),
		    		query.append(new Double(rowObjects[24]==null?"0.0":rowObjects[24].toString())+",");//DIGVCOM NUMERIC(14,2),
		    		query.append("'"+rowObjects[25]+"',");//DTIDREF CHAR(2),
		    		query.append("'"+rowObjects[26]+"',");//DNDOREF CHAR(30),
		    		
		    		if(rowObjects[27]!=null){
		    			DateFormat df = new SimpleDateFormat("dd/MM/yyyy");
				        GregorianCalendar calendar = new GregorianCalendar();
				        calendar.setTime(df.parse(rowObjects[27].toString()));
						
						String year=String.valueOf(calendar.get(Calendar.YEAR));
						String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
						month=fill(month,2);
						String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
						day=fill(day,2);
						
						query.append("CDATE('"+day+month+year+"','ddMMyyyy'),");//DFECREF DATE,
		    		}else{
		    			query.append("'',");
		    		}
		    		
		    		query.append(new Double(rowObjects[28]==null?"0.0":rowObjects[28].toString())+",");//DBIMREF NUMERIC(14,2),
		    		query.append(new Double(rowObjects[29]==null?"0.0":rowObjects[29].toString())+",");//DIGVREF NUMERIC(14,2),
		    		query.append("'"+rowObjects[30]+"'");//DMAQREF CHAR(20)
		    		
		    		query.append(");");
		    		
		    		System.out.println(query.toString());
	                stmt.execute(query.toString());
			    
	                
	              //(3)
	  	    	  //ASIGNA DATA :: INICIO
	  	    	  	rowObjects=new Object [31];
	                rowObjects[0]="05C";//CSUBDIA
	                rowObjects[1]=detalle.getCcompro();//CCOMPRO
	                rowObjects[2]="0003";//DSECUE 4 0 67
	                rowObjects[3]=detalle.getFechaComprobanteYYMMDD();//DFECCOM 6 0 67
	                rowObjects[4]="703312";//rowObjects[4]="704172";//DCUENTA 12 0 67 actualizado el 22/02/2020 nuevo pc 2020
	                rowObjects[5]="";//DCODANE 18 0 67
	                rowObjects[6]="400010";//DCENCOS 6 0 67
	                rowObjects[7]="MN";//DCODMON
	                rowObjects[8]="H";//DDH
	                rowObjects[9]=detalle.getSubtotalMN();//DIMPORT
	                rowObjects[10]="";//DTIPDOC 2 0 67
	                rowObjects[11]="";//DNUMDOC 2 0 67
	                rowObjects[12]=detalle.getFechaComprobanteYYMMDD();//DFECDOC 2 0 67
	                rowObjects[13]=detalle.getFechaComprobanteYYMMDD();//DFECVEN 2 0 67
	                rowObjects[14]="";//DAREA 2 0 67
	                rowObjects[15]="S";//DFLAG FLAG DE CONVERSIN DE MONEDA (S, N) 
	                rowObjects[16]="";//DXGLOSA GLOSA DEL MOVIMIENTO 
	                rowObjects[17]=detalle.getFechaComprobanteMMDDYYYY();//DDATE FECHA DE ACTUALIZACIN setFechaComprobanteMMDDYYYY
	                rowObjects[18]="";//DCODANE2 CDIGO DE ANEXO AUXILAR
	                rowObjects[19]=detalle.getSubtotalUS();//DUSIMPOR NUMERIC(14,2),
	                rowObjects[20]=detalle.getSubtotalMN();//DMNIMPOR NUMERIC(14,2),
	                rowObjects[21]="";//DCODARC
	                rowObjects[22]="";//FLAGX
	                rowObjects[23]="";//DMEDPAG
	                rowObjects[24]="0";//DIGVCOM NUMERIC(14,2),
	                rowObjects[25]="";//DTIDREF
	                rowObjects[26]="";//DNDOREF
	                rowObjects[27]="30/12/1899";//DFECREF
	                rowObjects[28]="0";//DBIMREF
	                rowObjects[29]="0";//DIGVREF
	                rowObjects[30]="";//DMAQREF
	                //ASIGNA DATA :: FIN 
	  	    	  
	  	    		query = new StringBuilder();
	  	    		query.append("insert into CD0002"+String.valueOf(periodo)+"(DSUBDIA,DCOMPRO,DSECUE,DFECCOM,DCUENTA,DCODANE,DCENCOS,DCODMON,DDH,DIMPORT,DTIPDOC,DNUMDOC,DFECDOC,DFECVEN,DAREA,DFLAG,DXGLOSA,DDATE,DCODANE2,DUSIMPOR,DMNIMPOR,DCODARC,FLAGX,DMEDPAG,DIGVCOM,DTIDREF,DNDOREF,DFECREF,DBIMREF,DIGVREF,DMAQREF) values(");
	  	    		query.append("'"+rowObjects[0]+"',");//DSUBDIA 4 0 67
	  	    		query.append("'"+rowObjects[1]+"',");//DCOMPRO 6 0 67
	  	    		query.append("'"+rowObjects[2]+"',");//DSECUE 4 0 67
	  	    		query.append("'"+rowObjects[3]+"',");//DFECCOM 6 0 67
	  	    		query.append("'"+rowObjects[4]+"',");//DCUENTA 12 0 67
	  	    		query.append("'"+rowObjects[5]+"',");//DCODANE 18 0 67
	  	    		query.append("'"+rowObjects[6]+"',");//DCENCOS 6 0 67
	  	    		query.append("'"+rowObjects[7]+"',");//DCODMON 2 0 67
	  	    		query.append("'"+rowObjects[8]+"',");//DDH 1 0 67
	  	    		query.append(new Double(rowObjects[9]==null?"0.0":rowObjects[9].toString())+",");//DIMPORT 14 2 78
	  	    		query.append("'"+rowObjects[10]+"',");//DTIPDOC 2 0 67
	  	    		query.append("'"+rowObjects[11]+"',");//DNUMDOC 20 0 67
	  	    		query.append("'"+rowObjects[12]+"',");//DFECDOC 6 0 67
	  	    		query.append("'"+rowObjects[13]+"',");//DFECVEN 6 0 67
	  	    		query.append("'"+rowObjects[14]+"',");//DAREA 3 0 67
	  	    		query.append("'"+rowObjects[15]+"',");//DFLAG 1 0 67
	  	    		query.append("'"+rowObjects[16]+"',");//DXGLOSA 30 0 67
	  	    		
	  	    		if(rowObjects[17]!=null){
	  	    			DateFormat df = new SimpleDateFormat("MM/dd/yyyy");
	  			        GregorianCalendar calendar = new GregorianCalendar();
	  			      calendar.setTime(df.parse(rowObjects[17].toString()));
	  					
	  					String year=String.valueOf(calendar.get(Calendar.YEAR));
	  					String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
	  					month=fill(month,2);
	  					String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
	  					day=fill(day,2);
	  					
	  					query.append("CDATE('"+month+day+year+"','MMddyyyy'),");//CDATE 8 0 68
	  	    		}else{
	  	    			query.append("'',");
	  	    		}
	  	    		query.append("'"+rowObjects[18]+"',");//DCODANE2 CHAR(18),
	  	    		query.append(new Double(rowObjects[19]==null?"0.0":rowObjects[19].toString())+",");//DUSIMPOR NUMERIC(14,2),
	  	    		query.append(new Double(rowObjects[20]==null?"0.0":rowObjects[20].toString())+",");//DMNIMPOR NUMERIC(14,2),
	  	    		query.append("'"+rowObjects[21]+"',");//DCODARC CHAR(2),
	  	    		query.append("'"+rowObjects[22]+"',");//FLAGX CHAR(1),
	  	    		query.append("'"+rowObjects[23]+"',");//DMEDPAG CHAR(8),
	  	    		query.append(new Double(rowObjects[24]==null?"0.0":rowObjects[24].toString())+",");//DIGVCOM NUMERIC(14,2),
	  	    		query.append("'"+rowObjects[25]+"',");//DTIDREF CHAR(2),
	  	    		query.append("'"+rowObjects[26]+"',");//DNDOREF CHAR(30),
	  	    		
	  	    		if(rowObjects[27]!=null){
	  	    			DateFormat df = new SimpleDateFormat("dd/MM/yyyy");
	  			        GregorianCalendar calendar = new GregorianCalendar();
	  			        calendar.setTime(df.parse(rowObjects[27].toString()));
	  					
	  					String year=String.valueOf(calendar.get(Calendar.YEAR));
	  					String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
	  					month=fill(month,2);
	  					String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
	  					day=fill(day,2);
	  					
	  					query.append("CDATE('"+day+month+year+"','ddMMyyyy'),");//DFECREF DATE,
	  	    		}else{
	  	    			query.append("'',");
	  	    		}
	  	    		
	  	    		query.append(new Double(rowObjects[28]==null?"0.0":rowObjects[28].toString())+",");//DBIMREF NUMERIC(14,2),
	  	    		query.append(new Double(rowObjects[29]==null?"0.0":rowObjects[29].toString())+",");//DIGVREF NUMERIC(14,2),
	  	    		query.append("'"+rowObjects[30]+"'");//DMAQREF CHAR(20)
	  	    		
	  	    		query.append(");");
	  	    		
	  	    		System.out.println(query.toString());
	                stmt.execute(query.toString());
            }
              
		    stmt.close();
            conn.close();
		}
        catch( SQLException sqle )
        {
            do
            {
                System.out.println(sqle.getMessage());
                System.out.println("Error Code:"+sqle.getErrorCode());
                System.out.println("SQL State:"+sqle.getSQLState());
                sqle.printStackTrace();
            }while((sqle=sqle.getNextException())!=null);
        }
        catch( Exception e )
        {
            System.out.println(e.getMessage());
            e.printStackTrace();
        }
	}
	
	public void createAnexoDBF(List<Cliente> lheader)throws DBFException, IOException,ParseException {
		  try{
			Class.forName("com.caigen.sql.dbf.DBFDriver");
			
            Properties props = new Properties();
            props.setProperty("delayedClose", "0");
            props.setProperty("versionNumber", "F5");
            
            Connection conn = DriverManager.getConnection(getsJdbURL(), props);
            Statement stmt = conn.createStatement(ResultSet.TYPE_SCROLL_SENSITIVE, ResultSet.CONCUR_UPDATABLE);

            String sql="drop table if exists CAN02;";
            stmt.execute(sql);
            
            sql="create table if not exists CAN02(AVANEXO CHAR(1),ACODANE CHAR(18),ADESANE CHAR(40),AREFANE CHAR(50),ARUC CHAR(18),ACODMON CHAR(2),AESTADO CHAR(1),ADATE DATE,AHORA CHAR(6),APATERNO CHAR(20),AMATERNO CHAR(20),ANOMBRE CHAR(20),AFORMSUS CHAR(8),ATELEFO CHAR(30),ATIPTRA CHAR(1),APROVIN CHAR(30),ADEPART CHAR(30),APAIS CHAR(30),AZONPOS CHAR(10),ANOMREP CHAR(40),ACARREP CHAR(20),AEMAIL CHAR(80),AHOST CHAR(80),ADOCIDE CHAR(2));";
            stmt.execute(sql);
	              
            for(Cliente header:lheader){
	              	//ASIGNA DATA :: INICIO
	                Object []rowObjects=new Object [24];
	                rowObjects[0]="C";//AVANEXO 1 0 67
		    		rowObjects[1]=header.getNroDocumento();//ACODANE 18 0 67
		    		rowObjects[2]=header.getDenominacion();//ADESANE 40 0 67
		    		rowObjects[3]="";//AREFANE 50 0 67
		    		rowObjects[4]=header.getNroDocumento();//ARUC 18 0 67
		    		rowObjects[5]="";//ACODMON 2 0 67
		    		rowObjects[6]="V";//AESTADO 1 0 67
		    		rowObjects[7]=header.getAdate();//ADATA 6 0 67
		    		rowObjects[8]="";//AHORA 6 0 67
		    		rowObjects[9]="";//APATERNO 20 0 67
		    		rowObjects[10]="";//AMATERNO 20 0 67
		    		rowObjects[11]="";//ANOMBRE 20 0 67
		    		rowObjects[12]="";//AFORMSUS 8 0 67
		    		rowObjects[13]="";//ATELEFO 30 0 67
		    		rowObjects[14]="";//ATIPTRA 1 0 67
		    		rowObjects[15]="";//APROVIN 30 0 67
		    		rowObjects[16]="";//ADEPART 30 0 67
		    		rowObjects[17]="";//APAIS 30 0 67
		    		rowObjects[18]="";//AZONPOS 10 0 67
		    		rowObjects[19]="";//ANOMREP 40 0 67
		    		rowObjects[20]="";//ACARREP 20 0 67
		    		rowObjects[21]="";//AEMAIL 80 0 67
		    		rowObjects[22]="";//AHOST 80 0 67
		    		rowObjects[23]=header.getAdocide();//ADOCIDE 2 0 67
		    		
	                //ASIGNA DATA :: FIN
	              
		    		StringBuilder query = new StringBuilder();
		    		query.append("insert into CAN02(AVANEXO,ACODANE,ADESANE,AREFANE,ARUC,ACODMON,AESTADO,ADATE,AHORA,APATERNO,AMATERNO,ANOMBRE,AFORMSUS,ATELEFO,ATIPTRA,APROVIN,ADEPART,APAIS,AZONPOS,ANOMREP,ACARREP,AEMAIL,AHOST,ADOCIDE) values(");
		    		query.append("'"+rowObjects[0]+"',");//AVANEXO 1 0 67
		    		query.append("'"+rowObjects[1]+"',");//ACODANE 18 0 67
		    		query.append("'"+rowObjects[2]+"',");//ADESANE 40 0 67
		    		query.append("'"+rowObjects[3]+"',");//AREFANE 50 0 67
		    		query.append("'"+rowObjects[4]+"',");//ARUC 18 0 67
		    		query.append("'"+rowObjects[5]+"',");//ACODMON 2 0 67
		    		query.append("'"+rowObjects[6]+"',");//AESTADO 1 0 67
		    		if(rowObjects[7]!=null){
		    			DateFormat df = new SimpleDateFormat("dd/MM/yyyy");
	  			        GregorianCalendar calendar = new GregorianCalendar();
	  			        calendar.setTime(df.parse(rowObjects[7].toString()));
	  					
	  					String year=String.valueOf(calendar.get(Calendar.YEAR));
	  					String month=String.valueOf(calendar.get(Calendar.MONTH) + 1);
	  					month=fill(month,2);
	  					String day=String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));
	  					day=fill(day,2);
	  					
	  					query.append("CDATE('"+month+day+year+"','MMddyyyy'),");//CDATE 8 0 68
		    		}else{
		    			query.append("'',");//DDATE 8 0 68
		    		}
		    		query.append("'"+rowObjects[8]+"',");//AHORA 6 0 67
		    		query.append("'"+rowObjects[9]+"',");//APATERNO 20 0 67
		    		query.append("'"+rowObjects[10]+"',");//AMATERNO 20 0 67
		    		query.append("'"+rowObjects[11]+"',");//ANOMBRE 20 0 67
		    		query.append("'"+rowObjects[12]+"',");//AFORMSUS 8 0 67
		    		query.append("'"+rowObjects[13]+"',");//ATELEFO 30 0 67
		    		query.append("'"+rowObjects[14]+"',");//ATIPTRA 1 0 67
		    		query.append("'"+rowObjects[15]+"',");//APROVIN 30 0 67
		    		query.append("'"+rowObjects[16]+"',");//ADEPART 30 0 67
		    		query.append("'"+rowObjects[17]+"',");//APAIS 30 0 67
		    		query.append("'"+rowObjects[18]+"',");//AZONPOS 10 0 67
		    		query.append("'"+rowObjects[19]+"',");//ANOMREP 40 0 67
		    		query.append("'"+rowObjects[20]+"',");//ACARREP 20 0 67
		    		query.append("'"+rowObjects[21]+"',");//AEMAIL 80 0 67
		    		query.append("'"+rowObjects[22]+"',");//AHOST 80 0 67
		    		query.append("'"+rowObjects[23]+"'");//ADOCIDE 2 0 67
		    		query.append(");");
		    		System.out.println(query.toString());
		            stmt.execute(query.toString());
              }
			    stmt.close();
	            conn.close();
	        }
	        catch( SQLException sqle )
	        {
	            do
	            {
	                System.out.println(sqle.getMessage());
	                System.out.println("Error Code:"+sqle.getErrorCode());
	                System.out.println("SQL State:"+sqle.getSQLState());
	                sqle.printStackTrace();
	            }while((sqle=sqle.getNextException())!=null);
	        }
	        catch( Exception e )
	        {
	            System.out.println(e.getMessage());
	            e.printStackTrace();
	        }
    }
	
	public static String fill(String text, int size) {
        StringBuilder builder = new StringBuilder(text);
        while (builder.length() < size) {
            builder.insert(0,'0');
        }
        return builder.toString();
    }
}